==> cuda-11.2-8.1-1.5.5-sources.jar: org/bytedeco/cuda/presets/nppist.java <==
/*
 * Copyright (C) 2015-2020 Samuel Audet
 *
 * Licensed either under the Apache License, Version 2.0, or (at your option)
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation (subject to the "Classpath" exception),
 * either version 2, or any later version (collectively, the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     http://www.gnu.org/licenses/
 *     http://www.gnu.org/software/classpath/license.html
 *
 * or as provided in the LICENSE.txt file that accompanied this code.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bytedeco.cuda.presets;

import org.bytedeco.javacpp.annotation.NoException;
import org.bytedeco.javacpp.annotation.Platform;
import org.bytedeco.javacpp.annotation.Properties;
import org.bytedeco.javacpp.tools.Info;
import org.bytedeco.javacpp.tools.InfoMap;
import org.bytedeco.javacpp.tools.InfoMapper;

/**
 *
 * @author Samuel Audet
 */
@Properties(inherit = nppc.class, value = {
    @Platform(include = {"<nppi_statistics_functions.h>", "<nppi_linear_transforms.h>"}, link = "nppist@.11"),
    @Platform(value = "windows-x86_64", preload = "nppist64_11")},
        global = "org.bytedeco.cuda.global.nppist")
@NoException
public class nppist implements InfoMapper {
    public void map(InfoMap infoMap) {
        infoMap.put(new Info("nppiEvenLevelsHost_32s_Ctx", "nppiHistogramEvenGetBufferSize_16s_AC4R_Ctx",
                             "nppiMSEBatchGetBufferHostSize_8u_C1R", "nppiMSEBatchGetBufferHostSize_8u_C3R",
                             "nppiHistogramEvenGetBufferSize_16s_C1R_Ctx", "nppiHistogramEvenGetBufferSize_16s_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16s_C4R_Ctx", "nppiHistogramEvenGetBufferSize_16u_AC4R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16u_C1R_Ctx", "nppiHistogramEvenGetBufferSize_16u_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16u_C4R_Ctx", "nppiHistogramEvenGetBufferSize_8u_AC4R_Ctx",
                             "nppiHistogramEvenGetBufferSize_8u_C1R_Ctx", "nppiHistogramEvenGetBufferSize_8u_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_8u_C4R_Ctx", "nppiHistogramRangeGetBufferSize_16s_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16s_C1R_Ctx", "nppiHistogramRangeGetBufferSize_16s_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16s_C4R_Ctx", "nppiHistogramRangeGetBufferSize_16u_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16u_C1R_Ctx", "nppiHistogramRangeGetBufferSize_16u_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16u_C4R_Ctx", "nppiHistogramRangeGetBufferSize_32f_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_32f_C1R_Ctx", "nppiHistogramRangeGetBufferSize_32f_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_32f_C4R_Ctx", "nppiHistogramRangeGetBufferSize_8u_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_8u_C1R_Ctx", "nppiHistogramRangeGetBufferSize_8u_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_8u_C4R_Ctx", "nppiNormRelInfGetBufferHostSize_32s_C1R").skip());
    }
}

==> cuda-12.9-9.10-1.5.12-sources.jar: org/bytedeco/cuda/presets/nppist.java <==
/*
 * Copyright (C) 2015-2023 Samuel Audet
 *
 * Licensed either under the Apache License, Version 2.0, or (at your option)
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation (subject to the "Classpath" exception),
 * either version 2, or any later version (collectively, the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     http://www.gnu.org/licenses/
 *     http://www.gnu.org/software/classpath/license.html
 *
 * or as provided in the LICENSE.txt file that accompanied this code.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bytedeco.cuda.presets;

import org.bytedeco.javacpp.annotation.NoException;
import org.bytedeco.javacpp.annotation.Platform;
import org.bytedeco.javacpp.annotation.Properties;
import org.bytedeco.javacpp.tools.Info;
import org.bytedeco.javacpp.tools.InfoMap;
import org.bytedeco.javacpp.tools.InfoMapper;

/**
 *
 * @author Samuel Audet
 */
@Properties(inherit = nppc.class, value = {
    @Platform(include = {"<nppi_statistics_functions.h>", "<nppi_linear_transforms.h>"}, link = "nppist@.12"),
    @Platform(value = "windows-x86_64", preload = "nppist64_12")},
        global = "org.bytedeco.cuda.global.nppist")
@NoException
public class nppist implements InfoMapper {
    public void map(InfoMap infoMap) {
        infoMap.put(new Info("nppiEvenLevelsHost_32s_Ctx", "nppiHistogramEvenGetBufferSize_16s_AC4R_Ctx",
                             "nppiMSEBatchGetBufferHostSize_8u_C1R", "nppiMSEBatchGetBufferHostSize_8u_C3R",
                             "nppiHistogramEvenGetBufferSize_16s_C1R_Ctx", "nppiHistogramEvenGetBufferSize_16s_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16s_C4R_Ctx", "nppiHistogramEvenGetBufferSize_16u_AC4R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16u_C1R_Ctx", "nppiHistogramEvenGetBufferSize_16u_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_16u_C4R_Ctx", "nppiHistogramEvenGetBufferSize_8u_AC4R_Ctx",
                             "nppiHistogramEvenGetBufferSize_8u_C1R_Ctx", "nppiHistogramEvenGetBufferSize_8u_C3R_Ctx",
                             "nppiHistogramEvenGetBufferSize_8u_C4R_Ctx", "nppiHistogramRangeGetBufferSize_16s_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16s_C1R_Ctx", "nppiHistogramRangeGetBufferSize_16s_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16s_C4R_Ctx", "nppiHistogramRangeGetBufferSize_16u_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16u_C1R_Ctx", "nppiHistogramRangeGetBufferSize_16u_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_16u_C4R_Ctx", "nppiHistogramRangeGetBufferSize_32f_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_32f_C1R_Ctx", "nppiHistogramRangeGetBufferSize_32f_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_32f_C4R_Ctx", "nppiHistogramRangeGetBufferSize_8u_AC4R_Ctx",
                             "nppiHistogramRangeGetBufferSize_8u_C1R_Ctx", "nppiHistogramRangeGetBufferSize_8u_C3R_Ctx",
                             "nppiHistogramRangeGetBufferSize_8u_C4R_Ctx", "nppiNormRelInfGetBufferHostSize_32s_C1R",
                             "nppiCrossCorrValid_NormLevel_64f_AC4R_Ctx").skip());
    }
}
